==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/opensearch/kotlin/inputs/OutboundConnectionLocalDomainInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opensearch.kotlin.inputs

import com.pulumi.aws.opensearch.inputs.OutboundConnectionLocalDomainInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property domainName The name of the local domain.
 * @property ownerId The Account ID of the owner of the local domain.
 * @property region The region of the local domain.
 */
public data class OutboundConnectionLocalDomainInfoArgs(
    public val domainName: Output<String>,
    public val ownerId: Output<String>,
    public val region: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.opensearch.inputs.OutboundConnectionLocalDomainInfoArgs> {
    override fun toJava(): com.pulumi.aws.opensearch.inputs.OutboundConnectionLocalDomainInfoArgs =
        com.pulumi.aws.opensearch.inputs.OutboundConnectionLocalDomainInfoArgs.builder()
            .domainName(domainName.applyValue({ args0 -> args0 }))
            .ownerId(ownerId.applyValue({ args0 -> args0 }))
            .region(region.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [OutboundConnectionLocalDomainInfoArgs].
 */
@PulumiTagMarker
public class OutboundConnectionLocalDomainInfoArgsBuilder internal constructor() {
    private var domainName: Output<String>? = null

    private var ownerId: Output<String>? = null

    private var region: Output<String>? = null

    /**
     * @param value The name of the local domain.
     */
    @JvmName("imdwqkxcsvsymqhc")
    public suspend fun domainName(`value`: Output<String>) {
        this.domainName = value
    }

    /**
     * @param value The Account ID of the owner of the local domain.
     */
    @JvmName("lvhjwpiokfmhkqwy")
    public suspend fun ownerId(`value`: Output<String>) {
        this.ownerId = value
    }

    /**
     * @param value The region of the local domain.
     */
    @JvmName("yereqhdoolkwwlvm")
    public suspend fun region(`value`: Output<String>) {
        this.region = value
    }

    /**
     * @param value The name of the local domain.
     */
    @JvmName("yjtcfkwcyqmsshux")
    public suspend fun domainName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.domainName = mapped
    }

    /**
     * @param value The Account ID of the owner of the local domain.
     */
    @JvmName("syclqorgtepcsctd")
    public suspend fun ownerId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ownerId = mapped
    }

    /**
     * @param value The region of the local domain.
     */
    @JvmName("venakkxmvcjcqtuy")
    public suspend fun region(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.region = mapped
    }

    internal fun build(): OutboundConnectionLocalDomainInfoArgs =
        OutboundConnectionLocalDomainInfoArgs(
            domainName = domainName ?: throw PulumiNullFieldException("domainName"),
            ownerId = ownerId ?: throw PulumiNullFieldException("ownerId"),
            region = region ?: throw PulumiNullFieldException("region"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/opensearch/kotlin/inputs/OutboundConnectionLocalDomainInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opensearch.kotlin.inputs

import com.pulumi.aws.opensearch.inputs.OutboundConnectionLocalDomainInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property domainName The name of the local domain.
 * @property ownerId The Account ID of the owner of the local domain.
 * @property region The region of the local domain.
 */
public data class OutboundConnectionLocalDomainInfoArgs(
    public val domainName: Output<String>,
    public val ownerId: Output<String>,
    public val region: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.opensearch.inputs.OutboundConnectionLocalDomainInfoArgs> {
    override fun toJava(): com.pulumi.aws.opensearch.inputs.OutboundConnectionLocalDomainInfoArgs =
        com.pulumi.aws.opensearch.inputs.OutboundConnectionLocalDomainInfoArgs.builder()
            .domainName(domainName.applyValue({ args0 -> args0 }))
            .ownerId(ownerId.applyValue({ args0 -> args0 }))
            .region(region.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [OutboundConnectionLocalDomainInfoArgs].
 */
@PulumiTagMarker
public class OutboundConnectionLocalDomainInfoArgsBuilder internal constructor() {
    private var domainName: Output<String>? = null

    private var ownerId: Output<String>? = null

    private var region: Output<String>? = null

    /**
     * @param value The name of the local domain.
     */
    @JvmName("rbiqacekbwhfwqac")
    public suspend fun domainName(`value`: Output<String>) {
        this.domainName = value
    }

    /**
     * @param value The Account ID of the owner of the local domain.
     */
    @JvmName("cswkgdrvddwcshsg")
    public suspend fun ownerId(`value`: Output<String>) {
        this.ownerId = value
    }

    /**
     * @param value The region of the local domain.
     */
    @JvmName("kavkajkfbrfxytpw")
    public suspend fun region(`value`: Output<String>) {
        this.region = value
    }

    /**
     * @param value The name of the local domain.
     */
    @JvmName("vfqjbdvgnoffaerm")
    public suspend fun domainName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.domainName = mapped
    }

    /**
     * @param value The Account ID of the owner of the local domain.
     */
    @JvmName("mstblaejfnxymofl")
    public suspend fun ownerId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ownerId = mapped
    }

    /**
     * @param value The region of the local domain.
     */
    @JvmName("bxhjhrwgnauvidik")
    public suspend fun region(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.region = mapped
    }

    internal fun build(): OutboundConnectionLocalDomainInfoArgs =
        OutboundConnectionLocalDomainInfoArgs(
            domainName = domainName ?: throw PulumiNullFieldException("domainName"),
            ownerId = ownerId ?: throw PulumiNullFieldException("ownerId"),
            region = region ?: throw PulumiNullFieldException("region"),
        )
}
